==> disco_stu-1.3.4-py27_0.tar.bz2: lib/python2.7/site-packages/disco_stu/source_detection/sextractoretifile.py <==
import os, subprocess
import numpy as np
from astropy.io import fits
from astropy.table import Table
import time

from ..lookups.general_parameters import DQ_DATATYPE, DQ_BITMASK
from .etifile import ETIFile
from .. import arg_overwrite

# Move this to a more central place
X_IMAGE = 'X_IMAGE'
Y_IMAGE = 'Y_IMAGE'
FLUX = 'FLUX_ISO'
RA = 'ra'
DEC ='dec'

FLAGS_DTYPE = np.int16

PREFIX = "tmp"
SUFFIX = ".fits"
FLAGS_TO_MASK = None

class SExtractorETIFile(ETIFile):
    """This class coordinates the ETI files as it pertains to Sextractor
    tasks in general.

    """
    def __init__(self, input):
        """
        input : data_abstracton.multiinddata.MultiINDData instances

        """
        self._set_name(__name__)
        super(SExtractorETIFile, self).__init__(input)
        self._time = str(time.time())
        self._disk_file = None
        self._catalog_file = None

    def prepare(self):
        # This looks silly, but we're pretending the array data is a "file"
        array = self.name
        dq_exists = array.mask is not None
        self._catalog_file = PREFIX + self._time + '_cat' + SUFFIX
        filename = PREFIX + self._time + SUFFIX
        hdulist = fits.HDUList()
        hdulist.append(fits.ImageHDU(array.data,
                                     header=array.meta['hdu'], name='SCI'))
        self._sci_image = filename+'[0]'
        if dq_exists:
            hdulist.append(fits.ImageHDU(array.mask & DQ_BITMASK,
                                         header=array.meta['hdu'], name='DQ'))
        else:
            # Need a dummy DQ array because .param file needs a FLAG_IMAGE
            hdulist.append(fits.ImageHDU(np.zeros_like(array.data, dtype=DQ_DATATYPE),
                                         header=array.meta['hdu'], name='DQ'))
        self._dq_image = filename+'[1]'
        hdulist.writeto(filename, **{arg_overwrite : True})
        self._disk_file = filename

    def recover(self):
        objcat = Table.read(self._catalog_file)
        return objcat

    def clean(self, remove_inputs=True):
        if os.path.isfile(self._disk_file):
            os.remove(self._disk_file)
        if os.path.isfile(self._catalog_file):
            os.remove(self._catalog_file)

==> disco_stu-1.3.6-py36_0.tar.bz2: lib/python3.6/site-packages/disco_stu/source_detection/sextractoretifile.py <==
import os, subprocess
import numpy as np
from astropy.io import fits
from astropy.table import Table
import time

from ..lookups.general_parameters import DQ_DATATYPE, DQ_BITMASK
from .etifile import ETIFile

# Move this to a more central place
X_IMAGE = 'X_IMAGE'
Y_IMAGE = 'Y_IMAGE'
FLUX = 'FLUX_ISO'
RA = 'ra'
DEC ='dec'

FLAGS_DTYPE = np.int16

PREFIX = "tmp"
SUFFIX = ".fits"
FLAGS_TO_MASK = None

class SExtractorETIFile(ETIFile):
    """This class coordinates the ETI files as it pertains to Sextractor
    tasks in general.

    """
    def __init__(self, input):
        """
        input : data_abstracton.multiinddata.MultiINDData instances

        """
        self._set_name(__name__)
        super(SExtractorETIFile, self).__init__(input)
        self._time = str(time.time())
        self._disk_file = None
        self._catalog_file = None

    def prepare(self):
        # This looks silly, but we're pretending the array data is a "file"
        array = self.name
        dq_exists = array.mask is not None
        self._catalog_file = PREFIX + self._time + '_cat' + SUFFIX
        filename = PREFIX + self._time + SUFFIX
        hdulist = fits.HDUList()
        hdulist.append(fits.ImageHDU(array.data,
                                     header=array.meta['hdu'], name='SCI'))
        self._sci_image = filename+'[0]'
        if dq_exists:
            hdulist.append(fits.ImageHDU(array.mask & DQ_BITMASK,
                                         header=array.meta['hdu'], name='DQ'))
        else:
            # Need a dummy DQ array because .param file needs a FLAG_IMAGE
            hdulist.append(fits.ImageHDU(np.zeros_like(array.data, dtype=DQ_DATATYPE),
                                         header=array.meta['hdu'], name='DQ'))
        self._dq_image = filename+'[1]'
        try:
            hdulist.writeto(filename, overwrite=True)
        except AttributeError:
            hdulist.writeto(filename, clobber=True)
        self._disk_file = filename

    def recover(self):
        objcat = Table.read(self._catalog_file)
        return objcat

    def clean(self, remove_inputs=True):
        if os.path.isfile(self._disk_file):
            os.remove(self._disk_file)
        if os.path.isfile(self._catalog_file):
            os.remove(self._catalog_file)
